--
-- FOR HELP IN CONFIGURING THE CODE PLEASE READ THE COMMENTS IN EACH SECTION!!!
--

-- Font names and paths
	local fontStandard	= "Interface\\AddOns\\xFont\\Fonts\\Calibri.ttf";
	local fontFancy		= "Interface\\AddOns\\xFont\\Fonts\\Calibri.ttf";
	local fontSmall    	= "Interface\\AddOns\\xFont\\Fonts\\Calibri.ttf";
	local fontDamage	= "Interface\\AddOns\\xFont\\Fonts\\damagefont.ttf";
	local fontZone 		= "Interface\\Addons\\xFont\\Fonts\\zonefont.ttf";
	
	-- To add/change fonts:
	--	1) Copy your font into the Fonts folder in xFont
	--	2) Change the font above or add a new font.
	--	Example:
	--	local fontStandard	= "Interface\\AddOns\\xFont\\Fonts\\MyNewFont.ttf";
	--		or
	-- 	local newMyNewFont	= "Interface\\AddOns\\xFont\\Fonts\\MyNewFont.ttf";

-- Font Sizes
	local sizeSmall    	= 9;
	local sizeMedium   	= 11;
	local sizeLarge    	= 15;
	local sizeHuge     	= 17;
	local sizeInsane   	= 25;
	local sizeZoneText 	= 100;
	local sizeZoneSubText 	= 20;
	local sizeZonePVPText	= 30;
	
	-- To add/change sizes:
	--	1) Change the size above or add a new size to the list
	--	Example:
	--	local sizeSmall	= 15;
	--		or
	--	local newFontSize = 12;

-- Override default SetFont command
local function SetFont(obj, font, size, style, alpha, r, g, b, sr, sg, sb, sox, soy)
	obj:SetFont(font, size, style)
	if sr and sg and sb then obj:SetShadowColor(sr, sg, sb) end
	if sox and soy then obj:SetShadowOffset(sox, soy) end
	if r and g and b then obj:SetTextColor(r, g, b) end
	if alpha then obj:SetAlpha(r) end
end


local f = CreateFrame("Frame")
f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", function()

	-- To alter the fonts here is how the SetFont command works.
	-- You can use ONE of the 4 types.  To not use a specific variable simply replace
	-- its value with the word "nil" without the quotes.
	--
	-- Syntax:
	--	Simple:
	--		SetFont(BLIZZARD_NAME, FONT_NAME, FONT_SIZE, style);
	--		where:
	--		FONT_NAME = one of the font names defined above
	--		FONT_SIZE = one of the font sizes defined above
	--		style = a blizzard style variable.
	--			Style vars: nil, "OUTLINE", "THICKOUTLINE", "MONOCHROME",
	--				"OUTLINE, MONOCHROME", "THICKOUTLINE, MONOCHROME"
	--
	--	Alpha:
	--		SetFont(BLIZZARD_NAME, FONT_NAME, FONT_SIZE, style, alpha);
	--		where:
	--		alpha = opacity level from 0-255 for the font
	--
	--	Color:
	--	SetFont(BLIZZARD_NAME, FONT_NAME, FONT_SIZE, style, alpha, r, g, b, shadow_r, shadow_g, shadow_b, shadow_x, shadow_y);
	--		where:
	--		r,g,b = color values from 0-255 for red, blue and green of the font
	--
	--	Shadow:
	--	SetFont(BLIZZARD_NAME, FONT_NAME, FONT_SIZE, style, alpha, r, g, b, shadow_r, shadow_g, shadow_b, shadow_x, shadow_y);
	--		where:
	--		shadow_r,shadow_g,shadow_b = shadow color values from 0-255 for red, blue and green of the shadow
	--		shadow_x, shadow_y = numeric offset for x and y.
	--			for x: negative moves left, positive moves right
	--			for y: negative moves up, positive moves down
	

	-- Base fonts (derived from clearfont and tekticles)
	SetFont(SystemFont_Tiny				, fontSmall   , sizeSmall , nil);
	SetFont(SystemFont_Small			, fontSmall   , sizeSmall , nil);
	SetFont(SystemFont_Outline_Small		, fontSmall   , sizeSmall , "OUTLINE");
	SetFont(SystemFont_Shadow_Small			, fontSmall   , sizeSmall , nil);
	SetFont(SystemFont_InverseShadow_Small		, fontSmall   , sizeSmall , nil);
	SetFont(SystemFont_Med1				, fontStandard, sizeMedium, nil);
	SetFont(SystemFont_Shadow_Med1			, fontStandard, sizeMedium, nil);
	SetFont(SystemFont_Med2				, fontStandard, sizeMedium, nil);
	SetFont(SystemFont_Med3				, fontStandard, sizeMedium, nil);
	SetFont(SystemFont_Shadow_Med3			, fontStandard, sizeMedium, nil);
	SetFont(SystemFont_Large			, fontStandard, sizeLarge , nil);
	SetFont(SystemFont_Shadow_Large			, fontStandard, sizeLarge , nil);
	SetFont(SystemFont_Shadow_Huge1			, fontStandard, sizeHuge  , nil);
	SetFont(SystemFont_OutlineThick_Huge2		, fontStandard, sizeHuge  , "THICKOUTLINE");
	SetFont(SystemFont_Shadow_Outline_Huge2		, fontStandard, sizeHuge  , "THICKOUTLINE");
	SetFont(SystemFont_Shadow_Huge3			, fontStandard, sizeHuge  , nil);
	SetFont(SystemFont_OutlineThick_Huge4		, fontStandard, sizeHuge  , "THICKOUTLINE");
	SetFont(SystemFont_OutlineThick_WTF		, fontStandard, sizeInsane, "THICKOUTLINE");
	SetFont(NumberFont_Shadow_Small			, fontSmall   , sizeSmall , nil);
	SetFont(NumberFont_OutlineThick_Mono_Small	, fontStandard, sizeMedium, "OUTLINE");
	SetFont(NumberFont_Shadow_Med			, fontStandard, sizeMedium, nil);
	SetFont(NumberFont_Outline_Med			, fontStandard, sizeMedium, "OUTLINE");
	SetFont(NumberFont_Outline_Large		, fontStandard, sizeLarge , "OUTLINE");
	SetFont(NumberFont_Outline_Huge			, fontStandard, sizeHuge  , "OUTLINE");
	SetFont(QuestFont_Large				, fontFancy   , sizeMedium, nil);
	SetFont(QuestFont_Shadow_Huge			, fontFancy   , sizeHuge  , nil);
	SetFont(GameTooltipHeader			, fontStandard, sizeMedium, nil);
	SetFont(MailFont_Large				, fontFancy   , sizeMedium, nil);
	SetFont(SpellFont_Small				, fontSmall   , sizeSmall , nil);
	SetFont(InvoiceFont_Med				, fontStandard, sizeMedium, nil);
	SetFont(InvoiceFont_Small			, fontSmall   , sizeSmall , nil);
	SetFont(Tooltip_Med				, fontStandard, sizeMedium, nil);
	SetFont(Tooltip_Small				, fontSmall   , sizeSmall , nil);
	SetFont(AchievementFont_Small			, fontSmall   , sizeSmall , nil);
	SetFont(ReputationDetailFont			, fontSmall   , sizeSmall , nil);


	-- Zone fonts
	SetFont(ZoneTextString				, fontZone    , sizeZoneText, "OUTLINE");
	SetFont(PVPInfoTextString			, fontZone    , sizeZonePVPText, "OUTLINE");
	SetFont(SubZoneTextString			, fontZone    , sizeZoneSubText, "OUTLINE");
	PVPInfoTextString:SetText("");


	-- Game engine fonts
	STANDARD_TEXT_FONT = fontStandard;
	UNIT_NAME_FONT     = fontStandard;
	DAMAGE_TEXT_FONT   = fontDamage;
	NAMEPLATE_FONT     = fontStandard;
	

end)
